@@ -8,11 +8,20 @@ using BoundaryValueDiffEqMIRK
 using BoundaryValueDiffEqMIRKN
 using BoundaryValueDiffEqShooting
 using DiffEqBase: DiffEqBase, solve
+using OrdinaryDiffEqTsit5: Tsit5
 using Reexport: @reexport
 using SciMLBase
 
 @reexport using ADTypes, SciMLBase
 
+function SciMLBase.__init(prob::BVProblem; kwargs...)
+    return SciMLBase.__init(prob, Shooting(Tsit5()); kwargs...)
+end
+
+function SciMLBase.__solve(prob::BVProblem; kwargs...)
+    return SciMLBase.__solve(prob, Shooting(Tsit5()); kwargs...)
+end
+
 include("extension_algs.jl")
 
 export MIRK2, MIRK3, MIRK4, MIRK5, MIRK6
